@@ -2,7 +2,8 @@ package Inline;
 
 use strict;
 require 5.006;
-$Inline::VERSION = '0.47';
+$Inline::VERSION = '0.50';
+$Inline::VERSION = eval $Inline::VERSION;
 
 use AutoLoader 'AUTOLOAD';
 use Inline::denter;
@@ -62,6 +63,7 @@ my $default_config =
    REPORTBUG => 0,
    UNTAINT => 0,
    NO_UNTAINT_WARN => 0,
+   REWRITE_CONFIG_FILE => 0,
    SAFEMODE => -1,
    GLOBAL_LOAD => 0,
    BUILD_NOISY => 0,
@@ -719,22 +721,42 @@ sub check_config_file {
 	  $o->{CONFIG}{DIRECTORY} || $o->find_temp_dir;
     }
 
-    $o->create_config_file($DIRECTORY)
-      if not -e File::Spec->catfile($DIRECTORY, $configuration_file);
-
-    open CONFIG, "< ".File::Spec->catfile($DIRECTORY, $configuration_file)
-      or croak M17_config_open_failed($DIRECTORY);
-    my $config = join '', <CONFIG>;
-    close CONFIG;
-
-    croak M62_invalid_config_file(File::Spec->catfile($DIRECTORY, $configuration_file))
-      unless $config =~ /^version :/;
-    if(UNTAINT) {
-      warn "In Inline::check_config_file(): Blindly untainting Inline configuration file information.\n" unless $o->{CONFIG}{NO_UNTAINT_WARN};
-      ($config) = $config =~ /(.*)/s;
+    if($o->{CONFIG}{REWRITE_CONFIG_FILE}) {
+      if(-e File::Spec->catfile($DIRECTORY, $configuration_file)) {
+        my $unlink = unlink(File::Spec->catfile($DIRECTORY, $configuration_file));
+        if(!$unlink) {warn "REWRITE_CONFIG_FILE is set, but removal of config file failed"}
+        else {warn "config file removal successful\n" if $o->{CONFIG}{_TESTING}}
+      }
     }
 
-    %config = Inline::denter->new()->undent($config);
+       my $load_cfg = sub {
+           $o->create_config_file($DIRECTORY)
+             if not -e File::Spec->catfile($DIRECTORY, $configuration_file);
+
+           open CONFIG, "< ".File::Spec->catfile($DIRECTORY,$configuration_file)
+             or croak M17_config_open_failed($DIRECTORY);
+           my $config = join '', <CONFIG>;
+           close CONFIG;
+
+           croak M62_invalid_config_file(File::Spec->catfile($DIRECTORY,$configuration_file))
+             unless $config =~ /^version :/;
+           if(UNTAINT) {
+             warn "In Inline::check_config_file(): Blindly untainting Inline configuration file information.\n"
+               unless $o->{CONFIG}{NO_UNTAINT_WARN};
+             ($config) = $config =~ /(.*)/s;
+           }
+
+           %config = Inline::denter->new()->undent($config);
+       } ;
+
+       $load_cfg->() ;
+       if (! defined $config{languages}->{$o->{API}{language_id}}){
+        my $unlink = unlink(File::Spec->catfile($DIRECTORY, $configuration_file));
+        if(!$unlink) {warn "Failed to remove config file"}
+        else {warn "config file removed\n" if $o->{CONFIG}{_TESTING}}
+               $load_cfg->() ;
+       }
+
     $Inline::languages = $config{languages};
 
     {
@@ -783,15 +805,15 @@ sub create_config_file {
         my($v,$d,$f) = File::Spec->splitpath($inline);
         $f = "" if $f eq 'Inline.pm';
         $inline = File::Spec->catpath($v,$d,$f);
-        #my $INC = "-I$inline -I" .
-        #          join(" -I", grep {(-d File::Spec->catdir($_,"Inline") or
-        #                             -d File::Spec->catdir($_,"auto","Inline")
-	  #		            )} @INC);
-	#system "$perl $INC -MInline=_CONFIG_ -e1 $dir"
-        my @INC = map { "-I$_" }
+
+        # P::RD may be in a different PERL5LIB dir to Inline (as happens with cpan smokers).
+        # Therefore we need to grep for it - otherwise, if P::RD *is* in a different PERL5LIB
+        # directory the ensuing rebuilt @INC will not include that directory and attempts to use
+        # Inline::CPP (and perhaps other Inline modules) will fail because P::RD isn't found.
+        my @_inc = map { "-I$_" }
        ($inline,
-        grep {(-d File::Spec->catdir($_,"Inline") or -d File::Spec->catdir($_,"auto","Inline"))} @INC);
-       system $perl, @INC, "-MInline=_CONFIG_", "-e1", "$dir"
+        grep {(-d File::Spec->catdir($_,"Inline") or -d File::Spec->catdir($_,"auto","Inline") or -e File::Spec->catdir($_,"Parse/RecDescent.pm"))} @INC);
+       system $perl, @_inc, "-MInline=_CONFIG_", "-e1", "$dir"
 	  and croak M20_config_creation_failed($dir);
 	return;
     }
@@ -1024,7 +1046,7 @@ sub with_configs {
 #==============================================================================
 sub env_untaint {
     my $o = shift;
-    warn "In Inline::env_untaint() : Blindly untainting tainted fields in %ENV.\n" unless $o->{CONFIG}{NO_UNTAINT_WARN};
+        warn "In Inline::env_untaint() : Blindly untainting tainted fields in %ENV.\n" unless $o->{CONFIG}{NO_UNTAINT_WARN};
 
     {
     no warnings ('uninitialized'); # In case $ENV{$_} is set to undef.
@@ -1571,6 +1593,8 @@ config-${Config::Config{'archname'}}-$] file from the following Inline DIRECTORY
 
     $directory
 
+(And if that works, please file a bug report.)
+
 END
 }
 
